'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-5b8a09a8.js');

/**
 * Limits a value between a range.
 * @param value The value to clamp.
 * @param min Clamps the value to min if set.
 * @param max Clamps the value to max if set.
 */
const clamp = (value, min, max) => {
    if (min !== undefined && value < min) {
        value = min;
    }
    if (max !== undefined && value > max) {
        value = max;
    }
    return value;
};

const waterJarCss = ":host{width:100%;height:100%}:host svg{width:100%;height:100%}:host .water{-webkit-transition:-webkit-transform 300ms linear;transition:-webkit-transform 300ms linear;transition:transform 300ms linear;transition:transform 300ms linear, -webkit-transform 300ms linear}:host .water>*{-webkit-transition:fill 300ms linear;transition:fill 300ms linear}:host(.no-animation) .water{-webkit-transition:none !important;transition:none !important}:host(.no-animation) .water>*{-webkit-transition:none !important;transition:none !important}";

const WaterJarComponent = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.value = 0;
        this.color = '#488aff';
        this.shape = 'circle';
    }
    getValidShape() {
        switch (this.shape) {
            default:
            case 'circle':
            case 'round':
                return 'circle';
            case 'rect':
            case 'square':
                return 'rect';
        }
    }
    render() {
        const value = clamp(this.value, 0, 100);
        const color = this.color;
        const shape = this.getValidShape();
        return (index.h(index.Host, null, index.h("svg", { viewBox: "0 0 100 100", width: "100%", height: "100%" }, index.h("defs", null, index.h("mask", { id: "mask-circle" }, index.h("circle", { fill: "white", r: "50", cx: "50", cy: "50" })), index.h("mask", { id: "mask-rect" }, index.h("rect", { fill: "white", x: "0", y: "0", width: "100", height: "100" })), index.h("symbol", { id: "water" }, index.h("path", { d: "M200,109.992l-200,0.008l0,-110.016c16.668,0.001 33.334,5.016 50,5.016c16.666,0 33.333,-5.015 50,-5.016c16.668,0.001 33.334,5.016 50,5.016c16.665,0 33.333,-5.015 50,-5.016l0,110.008Z" }))), index.h("g", { mask: 'url(#mask-' + shape + ')' }, index.h("rect", { fill: "gray", "fill-opacity": "0.1", x: "0", y: "0", width: "100", height: "100" }), index.h("g", { class: "water", transform: 'translate(0,' + (100 - value * 1.05) + ')' }, index.h("use", { href: "#water", fill: color, "fill-opacity": "0.5", width: "200", height: "110" }, index.h("animate", { attributeType: "XML", attributeName: "x", from: "0", to: "-100", dur: "1.4s", repeatCount: "indefinite" })), index.h("use", { href: "#water", fill: color, width: "200", height: "110" }, index.h("animate", { attributeType: "XML", attributeName: "x", from: "-100", to: "0", dur: "0.7s", repeatCount: "indefinite" })))))));
    }
};
WaterJarComponent.style = waterJarCss;

exports.ui_water_jar = WaterJarComponent;
