import { Component, Prop, h, Host } from '@stencil/core';
import { clamp } from '../../utils/math';
export class WaterJarComponent {
    constructor() {
        this.value = 0;
        this.color = '#488aff';
        this.shape = 'circle';
    }
    getValidShape() {
        switch (this.shape) {
            default:
            case 'circle':
            case 'round':
                return 'circle';
            case 'rect':
            case 'square':
                return 'rect';
        }
    }
    render() {
        const value = clamp(this.value, 0, 100);
        const color = this.color;
        const shape = this.getValidShape();
        return (h(Host, null,
            h("svg", { viewBox: "0 0 100 100", width: "100%", height: "100%" },
                h("defs", null,
                    h("mask", { id: "mask-circle" },
                        h("circle", { fill: "white", r: "50", cx: "50", cy: "50" })),
                    h("mask", { id: "mask-rect" },
                        h("rect", { fill: "white", x: "0", y: "0", width: "100", height: "100" })),
                    h("symbol", { id: "water" },
                        h("path", { d: "M200,109.992l-200,0.008l0,-110.016c16.668,0.001 33.334,5.016 50,5.016c16.666,0 33.333,-5.015 50,-5.016c16.668,0.001 33.334,5.016 50,5.016c16.665,0 33.333,-5.015 50,-5.016l0,110.008Z" }))),
                h("g", { mask: 'url(#mask-' + shape + ')' },
                    h("rect", { fill: "gray", "fill-opacity": "0.1", x: "0", y: "0", width: "100", height: "100" }),
                    h("g", { class: "water", transform: 'translate(0,' + (100 - value * 1.05) + ')' },
                        h("use", { href: "#water", fill: color, "fill-opacity": "0.5", width: "200", height: "110" },
                            h("animate", { attributeType: "XML", attributeName: "x", from: "0", to: "-100", dur: "1.4s", repeatCount: "indefinite" })),
                        h("use", { href: "#water", fill: color, width: "200", height: "110" },
                            h("animate", { attributeType: "XML", attributeName: "x", from: "-100", to: "0", dur: "0.7s", repeatCount: "indefinite" })))))));
    }
    static get is() { return "ui-water-jar"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["water-jar.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["water-jar.css"]
    }; }
    static get properties() { return {
        "value": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "value",
            "reflect": false,
            "defaultValue": "0"
        },
        "color": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "color",
            "reflect": false,
            "defaultValue": "'#488aff'"
        },
        "shape": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "shape",
            "reflect": false,
            "defaultValue": "'circle'"
        }
    }; }
}
